/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Clippings.
 *
 * The Initial Developer of the Original Code is 
 * Alex Eng <ateng@users.sourceforge.net>.
 * Portions created by the Initial Developer are Copyright (C) 2007-2010
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * ***** END LICENSE BLOCK ***** */

Components.utils.import("resource://gre/modules/XPCOMUtils.jsm");


function nsClippingsToolbarService() {}

nsClippingsToolbarService.prototype = {
  // Constants
  _DEBUG:                true,
  _TOOLBAR_CHROME_URL:   "chrome://clippings/content/hostappToolbar.xul",
  _TOOLBAR_WND_NAME:     "ae_cliptb",
  _TOOLBAR_WND_FEATURES: "chrome,dialog=0,popup",

  // Private member variables
  _clippingsSvc:   null,
  _toolbarWnd:     null,
  _hidden:         null,

  // Component registration
  classDescription: "XPCOM component for experimental Clippings Toolbar",
  classID:          Components.ID("{67a3e1ce-9cc1-11dc-8314-0800200c9a66}"),
  contractID:       "clippings@mozdev.org/clippings-toolbar;1",
  QueryInterface:   XPCOMUtils.generateQI([Components.interfaces.nsIClippingsToolbarService])
};


nsClippingsToolbarService.prototype.init = function (aClippingsSvc)
{
  if (! this._clippingsSvc) {
    this._clippingsSvc = aClippingsSvc;
  }

  this._log("nsClippingsToolbarService.init(): Datasource URL: \"" + this._clippingsSvc.dataSourceURL + "\" (" + this._clippingsSvc.numItems + " items)");
};


nsClippingsToolbarService.prototype.open = function ()
{
  var rv;
  var parentWnd = null;
  var ww = Components.classes['@mozilla.org/embedcomp/window-watcher;1']
                     .getService(Components.interfaces.nsIWindowWatcher);

  // Leave the last argument null, or else a dialog box will be created.
  this._toolbarWnd = ww.openWindow(parentWnd, this._TOOLBAR_CHROME_URL,
				   this._TOOLBAR_WND_NAME,
				   this._TOOLBAR_WND_FEATURES,
				   null);

  this._hidden = false;
  rv = this._toolbarWnd.QueryInterface(Components.interfaces.nsIDOMWindow);
  return rv;
};


nsClippingsToolbarService.prototype.isOpen = function ()
{
  if (! this._toolbarWnd) {
    return false;
  }

  return (! this._toolbarWnd.closed);
};


nsClippingsToolbarService.prototype.close = function ()
{
  if (!this._toolbarWnd || this._toolbarWnd.closed) {
    return;
  }

  this._toolbarWnd.QueryInterface(Components.interfaces.nsIDOMWindowInternal)
                  .close();
  this._toolbarWnd = null;
};


nsClippingsToolbarService.prototype.getToolbarWnd = function ()
{
  return this._toolbarWnd;
};


nsClippingsToolbarService.prototype.setHidden = function (aHiddenFlag)
{
  this._hidden = aHiddenFlag;
};


nsClippingsToolbarService.prototype.isHidden = function ()
{
  return this._hidden;
};



//
// Private utility functions
//

nsClippingsToolbarService.prototype._log = function (aMessage)
{
  if (this._DEBUG) {
    var consoleSvc = Components.classes["@mozilla.org/consoleservice;1"]
                               .getService(Components.interfaces
			  	  	             .nsIConsoleService);
    consoleSvc.logStringMessage(aMessage);
  }
};



//
// Component registration
//

if (XPCOMUtils.generateNSGetFactory) {
  const NSGetFactory = XPCOMUtils.generateNSGetFactory([nsClippingsToolbarService]);
}
else {
  const NSGetModule = XPCOMUtils.generateNSGetModule([nsClippingsToolbarService]);
}


