/* ***** BEGIN LICENSE BLOCK *****
 * Version: MPL 1.1
 *
 * The contents of this file are subject to the Mozilla Public License Version
 * 1.1 (the "License"); you may not use this file except in compliance with
 * the License. You may obtain a copy of the License at
 * http://www.mozilla.org/MPL/
 *
 * Software distributed under the License is distributed on an "AS IS" basis,
 * WITHOUT WARRANTY OF ANY KIND, either express or implied. See the License
 * for the specific language governing rights and limitations under the
 * License.
 *
 * The Original Code is Clippings.
 *
 * The Initial Developer of the Original Code is 
 * Alex Eng <ateng@users.sourceforge.net>.
 * Portions created by the Initial Developer are Copyright (C) 2007-2010
 * the Initial Developer. All Rights Reserved.
 *
 * Contributor(s):
 *
 * ***** END LICENSE BLOCK ***** */

//
// Dependencies:
//  - utils.js (for aeClippingUtils object)
//


/*
 * Constructor for aeClippingInfo
 * Holds various properties of a clipping to be passed as an argument to
 * aeClippingSubst.processClippingText()
 */
function aeClippingInfo(aURI, aName, aText, aParentFolderName)
{
  this.uri   = aURI;
  this.name  = aName;
  this.text  = aText;
  this.parentFolderName = aParentFolderName;
}


/*
 * Constructor for aeClippingSubst
 * Performs substitution of variables embedded inside a clipping with either
 * predefined values or user-input text.
 */
function aeClippingSubst(aStringBundle)
{
  this._strBundle = aStringBundle;
}


aeClippingSubst.prototype.processClippingText = function (aClippingInfo)
{
  if ((/^\[NOSUBST\]/.test(aClippingInfo.name))) {
    return aClippingInfo.text;
  }

  var rv = "";
  var strBundle = this._strBundle;
  var prmptSvc = Components.classes["@mozilla.org/embedcomp/prompt-service;1"]
                           .getService(Components.interfaces.nsIPromptService);

  // Remember the value of the same placeholder that was filled in previously
  var knownTags = {};

  var fnReplace = function (str, p1, offset, s) {
    if (p1 in knownTags) {
      return knownTags[p1];
    }

    var rv = "";
    var title = strBundle.getString("substPromptTitle");
    var prmpt = strBundle.getString("substPromptText1") + p1 + strBundle.getString("substPromptText2");
    var defValue = { value: "" };
    var checkState = { value: null };
    
    prmptSvc.prompt(null, title, prmpt, defValue, null, checkState);
    knownTags[p1] = defValue.value;
    rv = defValue.value;
    
    return rv;
  };

  var utils = new aeClippingsUtils();
  var date = new Date();

  rv = aClippingInfo.text.replace(/\$\[DATE\]/gm, date.toLocaleDateString());
  rv = rv.replace(/\$\[TIME\]/gm, date.toLocaleTimeString());
  rv = rv.replace(/\$\[NAME\]/gm, aClippingInfo.name);
  rv = rv.replace(/\$\[_RDF_CLIPPING_URI\]/gm, aClippingInfo.uri);
  rv = rv.replace(/\$\[FOLDER\]/gm, aClippingInfo.parentFolderName);
  rv = rv.replace(/\$\[HOSTAPP\]/gm, utils.getHostAppName()
		  + " " + utils.getHostAppVersionStr());
  rv = rv.replace(/\$\[UA\]/gm, navigator.userAgent);
  rv = rv.replace(/\$\[(\w+)\]/gm, fnReplace);

  return rv;
};


